summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsobjectproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsobjectproxy.h')
-rw-r--r--kjsembed/jsobjectproxy.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/kjsembed/jsobjectproxy.h b/kjsembed/jsobjectproxy.h
index b302d4ad..8e620e2a 100644
--- a/kjsembed/jsobjectproxy.h
+++ b/kjsembed/jsobjectproxy.h
@@ -22,9 +22,9 @@
#ifndef KJSEMBEDJSOBJECTPROXY_H
#define KJSEMBEDJSOBJECTPROXY_H
#include "global.h"
-#include <qguardedptr.h>
-#include <qcstring.h>
-#include <qwidget.h>
+#include <tqguardedptr.h>
+#include <tqcstring.h>
+#include <tqwidget.h>
#include <kjs/object.h>
#include <kjsembed/jsproxy.h>
@@ -41,19 +41,19 @@ class KJSEmbedPart;
class JSObjectEventProxy;
/**
* A JS object that provides a binding to a QObject.
* <h3>Introduction</h3>
* This class defines a @ref KJS::ObjectImp that allows scripts to access
* the properties of a QObject. The scripts can also create child objects,
* load dialogs from .ui files created by Designer and navigate the object
* tree in a similar manner to the DCOP/QObject bridge.
* <h3>Example Usage</h3>
* The following example creates a @ref KJS::ObjectImp that provides
- * a binding to the properties of a @ref QLineEdit . This binding is
+ * a binding to the properties of a @ref TQLineEdit . This binding is
* then used to create a property 'edit' for the object 'jsparent'.
* <pre>
*
- * QLineEdit *edit = new QLineEdit();
+ * TQLineEdit *edit = new TQLineEdit();
* KJSEmbed::JSObjectProxy *proxy = new KJSEmbed::JSObjectProxy( js, edit );
* jsparent.put( js->globalExec(), "edit", proxy );
*
@@ -82,24 +82,24 @@ class KJSEMBED_EXPORT JSObjectProxy : public JSProxy
public:
/**
* Create a JS binding to the target object. The binding will allow scripts to
* access any QObject that is descended the target and no others.
*/
- JSObjectProxy( KJSEmbedPart *part, QObject *target );
+ JSObjectProxy( KJSEmbedPart *part, TQObject *target );
/**
* Create a JS binding to the target object. The binding will allow scripts to
* access any QObject that is descended from the specified root. If the specified
* root is 0 then access is granted to all objects.
*/
- JSObjectProxy( KJSEmbedPart *part, QObject *target, QObject *root );
+ JSObjectProxy( KJSEmbedPart *part, TQObject *target, TQObject *root );
/**
* Create a JS binding to the target object. The binding will allow scripts to
* access any QObject that is descended from the specified root, according to
* the specified @ref JSSecurityPolicy . If the specified root is 0 then access
* is granted to all objects.
*/
- JSObjectProxy( KJSEmbedPart *part, QObject *target, QObject *root, const JSSecurityPolicy *sp );
+ JSObjectProxy( KJSEmbedPart *part, TQObject *target, TQObject *root, const JSSecurityPolicy *sp );
virtual ~JSObjectProxy();
@@ -110,24 +110,24 @@ public:
KJS::Interpreter *interpreter() const { return js; }
/** Returns the root object that defines the limit of the scope of this proxy. */
- QObject *rootObject() const { return root; }
+ TQObject *rootObject() const { return root; }
- /** Returns the QObject the proxy is attached to. */
- QObject *object() const { return obj; }
+ /** Returns the TQObject the proxy is attached to. */
+ TQObject *object() const { return obj; }
/** Returns the className of the proxied object */
- QString typeName() const { return obj->className(); }
+ TQString typeName() const { return obj->className(); }
- /** Returns the associated QWidget, or 0 if the object is not a widget. */
- QWidget *widget() const
+ /** Returns the associated TQWidget, or 0 if the object is not a widget. */
+ TQWidget *widget() const
{
- QObject *w = obj;
- return (w && w->isWidgetType()) ? static_cast<QWidget *>(w) : 0;
+ TQObject *w = obj;
+ return (w && w->isWidgetType()) ? static_cast<TQWidget *>(w) : 0;
}
//void *toVoidStar() { return obj; }
//template<class T>
- //T *toNative(){ return dynamic_cast<QObject*>(obj); }
+ //T *toNative(){ return dynamic_cast<TQObject*>(obj); }
/** Returns true iff the content of this proxy inherits the specified base-class. */
bool inherits( const char *clazz ) { return obj->isA( clazz ); }
@@ -152,7 +152,7 @@ public:
virtual KJS::UString toString( KJS::ExecState *exec ) const;
/**
* Adds methods for traversing the QObject tree to the specified
* @ref KJS::Object . Only QObjects descended from the root specified
* in the constructor can be reached through JS proxies created with
* these bindings.
@@ -180,14 +180,14 @@ protected:
private:
bool isAllowed( KJS::Interpreter *js ) const;
- void addSlotBinding( const QCString &name, KJS::ExecState *exec, KJS::Object &object );
+ void addSlotBinding( const TQCString &name, KJS::ExecState *exec, KJS::Object &object );
private:
KJSEmbedPart *jspart;
KJS::Interpreter *js;
- QGuardedPtr<QObject> obj;
- QGuardedPtr<QObject> root;
- QGuardedPtr<JSObjectEventProxy> evproxy;
+ TQGuardedPtr<TQObject> obj;
+ TQGuardedPtr<TQObject> root;
+ TQGuardedPtr<JSObjectEventProxy> evproxy;
const JSSecurityPolicy *policy;
class JSObjectProxyPrivate *d;
friend class Bindings::JSObjectProxyImp;
@@ -41,19 +41,19 @@ class KJSEmbedPart;
class JSObjectEventProxy;
/**
- * A JS object that provides a binding to a QObject.
+ * A JS object that provides a binding to a TQObject.
* <h3>Introduction</h3>
* This class defines a @ref KJS::ObjectImp that allows scripts to access
@@ -41,19 +41,19 @@ class KJSEmbedPart;
* <h3>Introduction</h3>
* This class defines a @ref KJS::ObjectImp that allows scripts to access
- * the properties of a QObject. The scripts can also create child objects,
+ * the properties of a TQObject. The scripts can also create child objects,
* load dialogs from .ui files created by Designer and navigate the object
@@ -41,19 +41,19 @@ class KJSEmbedPart;
* load dialogs from .ui files created by Designer and navigate the object
- * tree in a similar manner to the DCOP/QObject bridge.
+ * tree in a similar manner to the DCOP/TQObject bridge.
* <h3>Example Usage</h3>
* The following example creates a @ref KJS::ObjectImp that provides
@@ -82,24 +82,24 @@ class KJSEMBED_EXPORT JSObjectProxy : public JSProxy
/**
* Create a JS binding to the target object. The binding will allow scripts to
- * access any QObject that is descended the target and no others.
+ * access any TQObject that is descended the target and no others.
*/
@@ -82,24 +82,24 @@ class KJSEMBED_EXPORT JSObjectProxy : public JSProxy
/**
* Create a JS binding to the target object. The binding will allow scripts to
- * access any QObject that is descended from the specified root. If the specified
+ * access any TQObject that is descended from the specified root. If the specified
* root is 0 then access is granted to all objects.
*/
@@ -82,24 +82,24 @@ class KJSEMBED_EXPORT JSObjectProxy : public JSProxy
/**
* Create a JS binding to the target object. The binding will allow scripts to
- * access any QObject that is descended from the specified root, according to
+ * access any TQObject that is descended from the specified root, according to
* the specified @ref JSSecurityPolicy . If the specified root is 0 then access
* is granted to all objects.
@@ -152,7 +152,7 @@ public:
virtual KJS::UString toString( KJS::ExecState *exec ) const;
/**
- * Adds methods for traversing the QObject tree to the specified
+ * Adds methods for traversing the TQObject tree to the specified
* @ref KJS::Object . Only QObjects descended from the root specified
* in the constructor can be reached through JS proxies created with